**************************************************************
FGMK - A interface to generate code, and develop 2d RPG Games.
**************************************************************

FGMK (Fan Game MaKer) is a PyQt tool to generate files that describe a 2D
TopDown RPG Game. A javascript engine is packed together to read that
description and run the game in a portable way.

Recommended Install and Run
---------------------------

For installing `pip3` in Ubuntu, use `sudo apt install python3-pip`.

    pip3 install fgmk

After install, just open a terminal and type:

    fgmk

Windows install and run
-----------------------

In Windows, install Python 3 from https://www.python.org/, and then open `cmd.exe` and type (press enter after):

    python -m pip install fgmk

To run, you can type the following in `cmd.exe` or the `run...` prompt

    python -m fgmk
